@@ -3,8 +3,6 @@ rpd.api
 ~~~~~~~
 The internal api of RPD.
 """
-from .event_factory import *
 from .gateway import *
 from .rest import *
 from .rest_factory import *
-from .shard import *
